{ pkgs ? import <nixpkgs> {} }: with pkgs;

let
  genodeVersion = "19.05";
  toolchain = import ../errata/toolchain.nix { inherit pkgs; };
  upstream = fetchFromGitHub {
    owner = "genodelabs";
    repo = "genode";
    rev = "19.05";
    sha256 = "01sgixyvsq5g7fd0nj9j67d9jma0bhlprwyjf21dql9hqn5k0ngf";
  };  
in
stdenv.mkDerivation {
  name = "genode-sdk-${genodeVersion}";
  version = genodeVersion;

  toolchain_dir = toolchain.out;

  inherit upstream;

  src = upstream;

  phases = [ "mainPhase" ];

  mainPhase = ''
    dest=$out/opt/genode
    mkdir -p $dest

    tar xf $src --strip-components=3 -C $dest

    for i in $dest/pkgconfig/*/*.pc; do
       substituteInPlace "$i" \
         --replace /opt/genode/sdk-${genodeVersion} $dest \
         --replace @TOOLCHAIN_DIR@ $toolchain_dir \
    ; done
  '';
}
